[![Docs](https://github.com/rouskinlab/RNA_data/actions/workflows/sphinx.yml/badge.svg)](https://github.com/rouskinlab/RNA_data/actions/workflows/sphinx.yml)


# RNA_data

A repo to manipulate the data for our RNA structure prediction model.

See [the docs](https://rouskinlab.github.io/RNA_data/) for more information.
